//
//
// Barcode API definitions for the H22
//
//
//
#pragma once

#define BCR_MAX_COMMAND				256

//
// BCR Event Name Definition
//
#define BCR_EVENT_SCAN_BARCODE		L"BcrScanBarcodeEvent"
#define BCR_EVENT_DEVICE_STATUS		L"BcrStatusChangeEvent"
#define BCR_EVENT_COMMAND_FAILED    L"BcrCommandFailedEvent"

//
// BCR Message Name Definition
//
#define WM_BCR_SCAN_NOTIFY			WM_APP + 2016
#define WM_BCR_STATUS_CHANGE		WM_APP + 2018
#define WM_BCR_COMMAND_ERROR        WM_APP + 2020

// The value of the trigger key status
typedef enum
{
	BCR_TRIGGER_DISABLE = 0,
	BCR_TRIGGER_ENABLE
} BCR_TRIGGER_STATUS;


// The value of the valid triggers
typedef enum
{
	BCR_TRIGGER_NONE = 0x00,			// Disable the hardware trigger key
	BCR_TRIGGER_SIDE_LEFT = 0x01,		// Hardware trigger key on the left side
	BCR_TRIGGER_SIDE_RIGHT = 0x02,		// Hardware trigger key on the right side
	BCR_TRIGGER_TOP_LEFT = 0x04,		// Hardware trigger key on the top left side
	BCR_TRIGGER_TOP_RIGHT = 0x08		// Hardware trigger key on the top right side
} BCR_TRIGGER_KEY;

// The value of the output mode
typedef enum
{
	BCR_OUTPUT_MODE_UNKNOWN = 0,
	BCR_OUTPUT_MODE_BUFFER,
	BCR_OUTPUT_MODE_KEYCODE,
	BCR_OUTPUT_MODE_CLIPBOARD
} BCR_OUTPUT_MODE;

// The value of the buzzer volume
typedef enum
{
	BCR_BUZZER_MUTE = 0,
	BCR_BUZZER_VOLUME_LOW,
	BCR_BUZZER_VOLUME_MIDDLE,
	BCR_BUZZER_VOLUME_HIGH
} BCR_BUZZER_VOLUME;

// The value of the read mode
typedef enum
{
	BCR_READMODE_SINGLE = 0,
	BCR_READMODE_MULTIPLE
} BCR_READ_MODE;

// The value of the read time
typedef enum
{
	BCR_READ_TIME_0 = 0,
	BCR_READ_TIME_1,
	BCR_READ_TIME_2,
	BCR_READ_TIME_3,
	BCR_READ_TIME_4,
	BCR_READ_TIME_5,
	BCR_READ_TIME_6,
	BCR_READ_TIME_7,
	BCR_READ_TIME_8,
	BCR_READ_TIME_9,
	BCR_READ_TIME_INDEFINITE = 0xff
} BCR_READ_TIME;

// The value of the margin check
typedef enum
{
	BCR_MARGIN_CHECK_NO = 0,
	BCR_MARGIN_CHECK_1OF7,
	BCR_MARGIN_CHECK_2OF7,
	BCR_MARGIN_CHECK_3OF7,
	BCR_MARGIN_CHECK_4OF7,
	BCR_MARGIN_CHECK_5OF7,
	BCR_MARGIN_CHECK_6OF7,
	BCR_MARGIN_CHECK_NORMAL
} BCR_MARGIN_CHECK;

// The value of the redundancy count
typedef enum
{
	BCR_REDUNDANCY_0 = 0,
	BCR_REDUNDANCY_1,
	BCR_REDUNDANCY_2,
	BCR_REDUNDANCY_3,
	BCR_REDUNDANCY_4,
	BCR_REDUNDANCY_5,
	BCR_REDUNDANCY_6,
	BCR_REDUNDANCY_7,
	BCR_REDUNDANCY_8,
} BCR_REDUNDANCY_COUNT;

// The value of the negative barcode flags
typedef enum
{
	BCR_BARCODE_UNKNOWN = 0,
	BCR_BARCODE_POSITIVE,
	BCR_BARCODE_NEGATIVE
} BCR_NEGATIVE_FLAG;

// The value of the scan angle
typedef enum
{
	BCR_SCANANGLE_NORMAL = 0,
	BCR_SCANANGLE_NARROW
} BCR_SCAN_ANGLE;

// The value of the read status
typedef enum
{
	BCR_READ_UNKNOWN = 0,
	BCR_READ_NOT_READY,
	BCR_READ_GOOD,
	BCR_READ_NO_DATA,
	BCR_READ_TIMEOUT,
	BCR_READ_OUTOFBUFFER,
	BCR_READ_ABORT
} BCR_READ_STATUS;

// The value of the status change notificaton of the barcode device
typedef enum
{
	BCR_STATUS_UNKNOWN = 0,
	BCR_STATUS_INITIALIZED,
	BCR_STATUS_READY,
	BCR_STATUS_DISABLED,
	BCR_STATUS_RESUMED,
	BCR_STATUS_UPDATED,
	BCR_STATUS_FAILED
} BCR_DEVICE_STATUS;

// The value of the the BCR module type
typedef enum
{
	BCR_MODULE_TYPE_UNKNOWN = 0,
	BCR_MODULE_TYPE_MDL,
	BCR_MODULE_TYPE_MDI
} BCR_MODULE_TYPE;


// The value of BCR_CODE_OPTIONS::dwMode
typedef enum
{
	BCR_OPTION_UNKNOWN = 0,
	BCR_CODE39_NORMAL,							// Code39
	BCR_CODE39_FULLASCII,						// Code39
	BCR_CODE39_FULLASCII_IF_POSSIBLE,			// Code39
	BCR_ITALIAN_PHARM_ONLY,						// Code39
	BCR_ITALIAN_PHARM_IF_POSSIBLE,				// Code39
	BCR_CODABAR_NORMAL,							// Codabar
	BCR_ABC_CODE_ONLY,							// Codabar
	BCR_CX_CODE_ONLY,							// Codabar
	BCR_CODABAR_ABC_CX,							// Codabar
	BCR_TELEPEN_MODE_NUMERIC,					// Telepen
	BCR_TELEPEN_MODE_ASCII,						// Telepen
	BCR_EAN128_DISABLE,							// Code128
	BCR_EAN128_ENABLE_ONLY,						// Code128
	BCR_EAN128_ENABLE_IFPOSSIBLE				// Code128
} BCR_OPTION_CODE_MODE;

// The value of BCR_CODE_OPTIONS::dwCheckDigit
typedef enum
{
	BCR_CHECK_DIGIT_UNKNOWN = 0,
	BCR_NOT_CHECK_DIGIT,
	BCR_CHECK_DIGIT,
	BCR_IATA_CHECK_FC_SN_ONLY,					// IATA
	BCR_IATA_CHECK_CPN_FC_SN,					// IATA
	BCR_IATA_CHECK_CPN_AC_FC_SN,				// IATA
	BCR_MSI_PLESSEY_1CD_MOD10,					// MSI_Plessey
	BCR_MSI_PLESSEY_MOD10_MOD10,				// MSI_Plessey
	BCR_MSI_PLESSEY_MOD10_MOD11,				// MSI_Plessey
	BCR_MSI_PLESSEY_MOD11_MOD10,				// MSI_Plessey
	BCR_CODE11_CHECK_1CD,						// Code11
	BCR_CODE11_CHECK_2CD,						// Code11
	BCR_CHECK_DIGIT_AUTO						// Code11
} BCR_OPTION_CHECK_CD;

// The value of BCR_CODE_OPTIONS::dwTransmitCD
typedef enum
{
	BCR_TRANSMIT_CD_UNKNOWN = 0,
	BCR_NOT_TRANSMIT_CD,
	BCR_TRANSMIT_CD,
	BCR_UPC_NOLEADING0_TRANSMITCD,				// UPC-A, UPC-E
	BCR_UPC_NOLEADING0_NOT_TRANSMITCD,			// UPC-A, UPC-E
	BCR_UPC_LEADING0_TRANSMITCD,				// UPC-A, UPC-E
	BCR_UPC_LEADING0_NOT_TRANSMITCD,			// UPC-A, UPC-E
	BCR_TRANSMIT_CD1,							// MSI_Plessey
	BCR_TRANSMIT_CD1_CD2						// MSI_Plessey
} BCR_OPTION_TRANSMIT_CD;

// The value of BCR_CODE_OPTIONS::dwTransmitSTSP
typedef enum
{
	BCR_TRANSMIT_STSP_UNKNOWN = 0,
	BCR_NOT_TRANSMIT_STSP,
	BCR_TRANSMIT_STSP,
	BCR_STSP_ABCD,								// Codabar
	BCR_STSP_abcd,								// Codabar
	BCR_STSP_ABCD_TN_E,							// Codabar
	BCR_STSP_abcd_tn_e,							// Codabar
	BCR_STSP_DC1DC2DC3DC4						// Codabar
} BCR_OPTION_TRANSMIT_STSP;

// The value of BCR_CODE_OPTIONS::dwSpecialOptions
typedef enum
{
	BCR_SPECIAL_OPTIONS_UNKNOWN = 0,
	BCR_DISABLE_CONCATENATION,					// Code39, Code128, Code93
	BCR_ENABLE_CONCATENATION,					// Code39, Code128, Code93
	BCR_DISABLE_CHECK_GAP,						// Codabar
	BCR_ENABLE_CHECK_GAP,						// Codabar
	BCR_D2OF5_NOT_CHECK_SPACE,					// 2of5 and S-Code
	BCR_D2OF5_CHECK_SPACE,						// 2of5 and S-Code
	BCR_NOT_TRANSMIT_AI,						// GS1 Databar
	BCR_TRANSMIT_AI								// GS1 Databar
} BCR_OPTION_SPECIAL_OPTIONS;

// The value of command error
typedef enum
{
	BCR_COMMAND_UNKNOWN = 0,
	BCR_COMMAND_INVALIDFORMAT,
	BCR_COMMAND_NAK,
	BCR_COMMAND_CONFLICT
} BCR_COMMAND_ERROR;

//
// BCR Structures
//
//
// This structure contains information identifying readable codes
//
typedef struct _BCR_READABLE_CODES {
	DWORD dwSize;
	DWORD dwValidFields;
	// bit 0~7
	DWORD UPC:1;
	DWORD UPC2:1;
	DWORD UPC5:1;
	DWORD EAN:1;
	DWORD EAN2:1;
	DWORD EAN5:1;
	DWORD Code39:1;
	DWORD TriOptic:1;
	// bit 8~15
	DWORD Codabar:1;
	DWORD Industrial2of5:1;
	DWORD Interleaved2of5:1;
	DWORD SCode:1;
	DWORD Matrix2of5:1;
	DWORD ChinesePostMatrix2of5:1;
	DWORD KoreanPostalAuthority:1;
	DWORD IATA:1;
	// bit 16~23
	DWORD MSIPlessey:1;
	DWORD Telepen:1;
	DWORD UKPlessey:1;
	DWORD Code128:1;
	DWORD Code93:1;
	DWORD Code11:1;
	DWORD GS1DataBar:1;
	DWORD GS1DataBarLimited:1;
	// bit 24~31
	DWORD GS1DataBarExpanded:1;
	DWORD DataMatrixECC000:1;
	DWORD DataMatrixECC200:1;
	DWORD Aztec:1;
	DWORD AztecRunes:1;
	DWORD QRCode:1;
	DWORD Maxicode:1;
	DWORD PDF417:1;
	// bit 32~33
	DWORD MicroPDF417:1;
	DWORD MicroQRCode:1;
} BCR_READABLE_CODES, *PBCR_READABLE_CODES;

// The value of code identifiers
typedef enum _BAR_CODE_ID
{
	CODE_UNKNOWN = 0,
	CODE_UPC_A,
	CODE_UPC_A_2,
	CODE_UPC_A_5,
	CODE_UPC_E,
	CODE_UPC_E_2,
	CODE_UPC_E_5,
	CODE_EAN13,
	CODE_EAN13_2,
	CODE_EAN13_5,
	CODE_EAN8,
	CODE_EAN8_2,
	CODE_EAN8_5,
	CODE_CODE39,
	CODE_CODE39_FULLASCII,
	CODE_CODE39_ITALIAN_PHARMACEUTICAL,
	CODE_CODABAR,
	CODE_CODABAR_ABC,
	CODE_CODABAR_CX,
	CODE_INDUSTRIAL_2OF5,
	CODE_INTERLEAVED_2OF5,
	CODE_SCODE,
	CODE_MATRIX_2OF5,
	CODE_IATA,
	CODE_MSI_PLESSEY,
	CODE_TELEPEN,
	CODE_UK_PLESSEY,
	CODE_CODE128,
	CODE_GS1_128,
	CODE_CODE93,
	CODE_CODE11,
	CODE_CHINESE_POST_MATRIX_2OF5,
	CODE_KOREAN_POSTAL_AUTHORITY,
	CODE_GS1_DATABAR,
	CODE_CC_A,
	CODE_CC_B,
	CODE_CC_C,
	CODE_DATAMATRIX,
	CODE_AZTEC,
	CODE_QR_CODE,
	CODE_MAXI_CODE,
	CODE_MICRO_PDF417,
	CODE_PDF417,
	CODE_MICRO_QR_CODE
} BAR_CODE_ID;

// The value of code options
typedef enum
{
	CODE_OPTION_UNKNOWN = 0,
	CODE_OPTION_UPCA,
	CODE_OPTION_UPCE,
	CODE_OPTION_EAN8,
	CODE_OPTION_EAN13,
	CODE_OPTION_CODE39,
	CODE_OPTION_CODABAR,
	CODE_OPTION_2OF5_SCODE,
	CODE_OPTION_KOREANPOSTALAUTHORITY,
	CODE_OPTION_IATA,
	CODE_OPTION_MSIPLESSEY,
	CODE_OPTION_TELEPEN,
	CODE_OPTION_UKPLESSEY,
	CODE_OPTION_CODE128_EAN128,
	CODE_OPTION_CODE93,
	CODE_OPTION_CODE11,
	CODE_OPTION_GS1DATABAR,
	CODE_OPTION_COMPOSITE,
	CODE_OPTION_PDF417,
	CODE_OPTION_MICROPDF417,
	BCR_MAX_OPTIONS, //  = CODE_OPTION_MICROPDF417
} SYMBOLOGY_ID;

//
// This structure contains information of a barcode specific options
//
typedef struct _BCR_CODE_OPTIONS {
	SYMBOLOGY_ID Symbology;
	DWORD dwMode;
	DWORD dwCheckDigit;
	DWORD dwTransmitCD;
	DWORD dwTransmitSTSP;
	DWORD dwSpecialOptions;
	DWORD dwReserved;
} BCR_CODE_OPTIONS, *PBCR_CODE_OPTIONS;

//
// This structure defines the read options
//
typedef struct _BCR_READ_OPTIONS {
	DWORD dwReadMode;
	DWORD dwReadTime;
	DWORD dwMargin;
	DWORD dwRedundancy;
	DWORD dwNegativeBarcode;
	DWORD dwScanAngle;
} BCR_READ_OPTIONS, *PBCR_READ_OPTIONS;

//
// This structure defines all barcode settings. 
// It is used by BCRGetSettings and BCRSetSettings
//
typedef struct _BCR_SETTINGS {
	DWORD dwPowerStatus;
	DWORD dwTriggerKeyState;
	DWORD dwTriggerKey;
	DWORD dwOutputMode;
	DWORD dwBuzzerVolume;
	TCHAR szBeepFile[MAX_PATH];
	DWORD dwVibrationTime;
	DWORD dwSuffixChar;
	BCR_READ_OPTIONS ReadOptions;
	BCR_READABLE_CODES ReadableCode;
	BCR_CODE_OPTIONS CodeOptions[BCR_MAX_OPTIONS];
	TCHAR szAdditonalCommands[BCR_MAX_COMMAND];
} BCR_SETTINGS, *PBCR_SETTINGS;

#ifdef __cplusplus
extern "C"
{
#endif

#ifdef BCRCTL_EXPORTS
#define BCRCTL_API __declspec(dllexport)
#else
#define BCRCTL_API __declspec(dllimport)
#endif

//
// BCRPowerOn
// Turn on the power of the barcode reader.
//
BCRCTL_API BOOL BCRPowerOn( void );

//
// BCRPowerOff
// Turn off the power of the barcode reader.
//
BCRCTL_API BOOL BCRPowerOff( void );

//
// BCRGetPowerStatus
// Retrieve the power status of the barcode reader.
//
BCRCTL_API BOOL BCRGetPowerStatus( BOOL* lpbPowerStatus );

//
// BCREnableTriggerKey
// Enable the trigger key of the device.
//
BCRCTL_API BOOL BCREnableTriggerKey( void );

//
// BCRDisableTriggerKey
// Disable the trigger key of the device.
//
BCRCTL_API BOOL BCRDisableTriggerKey( void );

//
// BCRGetTriggerKeyStatus
// Retrieve the trigger key status of the device.
//
BCRCTL_API BOOL BCRGetTriggerKeyStatus(DWORD* lpdwTriggerKeyStatus);

//
// BCRSetTriggerKey
// Set valid triggers.
//
BCRCTL_API BOOL BCRSetTriggerKey(DWORD dwTriggers);

//
// BCRGetTriggerKey
// Get the information of valid triggers.
//
BCRCTL_API BOOL BCRGetTriggerKey(DWORD* lpdwTriggers);

//
// BCRSetOutputMode
// Set barcode output mode.
//
BCRCTL_API BOOL BCRSetOutputMode(DWORD dwOutputMode);

//
// BCRGetOutputMode
// Retrieve the information about the barcode output mode.
//
BCRCTL_API BOOL BCRGetOutputMode(DWORD* lpdwOutputMode);

//
// BCRSetSuffix
// Set the suffix that will be transmitted follow the barcode data.
// The character should be one of the virtual key codes.
// The parameters: 0x30 - 0x39('0' thru '9'), 0x41 - 0x5A('a' thru 'z'), 
// VK_SEMICOLON(0xBA,';'), VK_EQUAL(0xBB,'='), VK_COMMA(0xBC,','),
// VK_HYPHEN(0xBD,'-'), VK_PERIOD(0xBE,'.'), VK_SLASH(0xBF,'/'),
// VK_BACKQUOTE(0xCO,'`'), VK_LBRACKET(0xDB,'['), VK_BACKSLASH(0xDC,'\\'), 
// VK_RBRACKET(0xDD,']'), VK_APOSTROPHE(0xDE,'\'')
//
BCRCTL_API BOOL BCRSetSuffix(BYTE vk);

//
// BCRGetSuffix
// Retrieve the suffix which is one of the virtual key codes.
//
BCRCTL_API BOOL BCRGetSuffix(BYTE* lpVk);

//
// BCRSetBuzzerStatus
// Set the beep option of the barcode reader.
//
BCRCTL_API BOOL BCRSetBuzzerStatus( DWORD dwBuzzerVolume, LPCTSTR lpszBeepFile);

//
// BCRGetBuzzerStatus
// Retrieve the buzzer status of the barcode reader.
//
BCRCTL_API BOOL BCRGetBuzzerStatus( DWORD* lpdwBuzzerVolume, LPTSTR lpszBeepFile, DWORD dwFilePathLength);

//
// BCRSetVibrationTime
// Enables or disable the vibrator of the barcode reader,
// and set the vibration time.
//
BCRCTL_API BOOL BCRSetVibrationTime(DWORD dwVibrationTime);

//
// BCRGetVibrationTime
// Retrieve the vibrator state of the barcode reader.
//
BCRCTL_API BOOL BCRGetVibrationTime(DWORD* lpdwVibrationTime);

// BCRGetSettings
// Retrieve the all settings information of the barcode reader;
// include the basic settings and decoder option settings.
//
BCRCTL_API BOOL BCRGetSettings(BCR_SETTINGS* lpSettingsData);

//
// BCRSetSettings
// Restore the all settings to the barcode reader; 
// include the basic settings and decoder option settings.
//
BCRCTL_API BOOL BCRSetSettings(BCR_SETTINGS* lpSettingsData);

//
// BCRSetDefault
// Set all settings of the barcode reader to the default.
//
BCRCTL_API BOOL BCRSetDefault(void);

//
// BCRGetDeviceNotification
// Retrieve information about the status change notification.
//
BCRCTL_API BOOL BCRGetDeviceNotification(UINT* lpDeviceChangeMsg, LPTSTR lpszDeviceChangeEventName, DWORD dwEventNameLength);

//
// BCRGetLasrDeviceEventStatus
// Retrieve the status of the barcode device.
//
BCRCTL_API BOOL BCRGetLastDeviceEventStatus(DWORD* lpdwStatus);

//
// Reading barcode
// BCRTriggerPress - Simulate a software trigger press.
//
BCRCTL_API BOOL BCRTriggerPress(void);


//
// BCRTriggerRelease
// Simulate a software trigger release.
//
BCRCTL_API BOOL BCRTriggerRelease(void);

//
// BCRGetBarcode
// Retrieve the barcode data and the information.
//
BCRCTL_API BOOL BCRGetBarcode(BYTE* lpDecodeData, DWORD* lpdwLength, DWORD* lpdwCodeType);

//
// BCRAbortScan
// Abort the process of a barcode scanning.
//
BCRCTL_API BOOL BCRAbortScan(void);

//
// BCRClearBuffer
//Clear the barcode data buffer in the BCR driver.
//
BCRCTL_API BOOL BCRClearBuffer(void);

//
// BCRGetReadNotification
// Retrieve information about the read notification.
//
BCRCTL_API BOOL BCRGetReadNotification(UINT* lpReadDataMsg, LPTSTR lpszReadDataEventName, DWORD dwEventNameLength);

//
// BCRGetLasrReadEventStatus
// Retrieve the status of the barcode scanning.
//
BCRCTL_API BOOL BCRGetLastReadEventStatus(DWORD* lpdwStatus);

// BCRSetReadableCode
// Enable or disable for scanning each barcode symbology.
//
BCRCTL_API BOOL BCRSetReadableCode(BCR_READABLE_CODES* lpReadableCodes);

//
// BCRGetReadableCode
// Retrieve information about readable code symbology.
//
BCRCTL_API BOOL BCRGetReadableCode(BCR_READABLE_CODES* lpReadableCodes);

//
// BCRSetCodeOptions
// Set the bar code specific option.
//
BCRCTL_API BOOL BCRSetCodeOptions(BCR_CODE_OPTIONS* lpCodeOptions);

//
// BCRGetCodeOptions
// Get the bar code specific option.
//
BCRCTL_API BOOL BCRGetCodeOptions(BCR_CODE_OPTIONS* lpCodeOptions);

//
// BCRSetSuffixChar
// Set the suffix that will be transmitted follow the barcode data.
// The character should be one of the 128 ASCII characters.
// This function sends a special command strings to the barcode module.
// dwSuffix 0x0D30 will result in "<barcode data>\x30\x0D"
BCRCTL_API BOOL BCRSetSuffixChar(DWORD dwSuffix);

//
// BCRGetSuffixChar
// Retrieve the suffix which is one of the 128 ASCII characters.
//
BCRCTL_API BOOL BCRGetSuffixChar(DWORD* lpdwSuffix);

//
// BCRSetReadMode
// Set the single read mode or multiple read mode.
//
BCRCTL_API BOOL BCRSetReadMode(DWORD dwReadMode);

//
// BCRGetReadMode
// Retrieve information about the read mode.
//
BCRCTL_API BOOL BCRGetReadMode(DWORD* lpdwReadMode);

//
// BCRSetReadTiemOption
// Set the read time option.
//
BCRCTL_API BOOL BCRSetReadTimeOption(DWORD dwReadTime);

//
// BCRGetReadTimeOption
// Retrieve information about read time.
//
BCRCTL_API BOOL BCRGetReadTimeOption(DWORD* lpdwReadTime);

//
// BCRSetMarginCheck
// Set the quiet zone option for the reader (margin check).
//
BCRCTL_API BOOL BCRSetMarginCheck(DWORD dwMargin);

//
// BCRGetMarginCheck
// Retrieve information about margin check.
//
BCRCTL_API BOOL BCRGetMarginCheck(DWORD* lpdwMargin);

//
// BCRSetRedundancy
// Set the redundancy count.
//
BCRCTL_API BOOL BCRSetRedundancy(DWORD dwRedundancyCount);

//
// BCRGetRedundancy
// Retrieve information about the redundancy count.
//
BCRCTL_API BOOL BCRGetRedundancy(DWORD* lpdwRedundancyCount);

//
// BCRSetNegativeBarcode
// Enable the reader to read a negative barcode.
//
BCRCTL_API BOOL BCRSetNegativeBarcode(DWORD dwNegativeFlag);

//
// BCRGetNegativeBarcode
// Retrieve information about reading the negative barcode.
//
BCRCTL_API BOOL BCRGetNegativeBarcode(DWORD* lpdwNegativeFlag);

//
// BCRSetScanAngle
// Set the laser scan angle, normal or narrow.
//
BCRCTL_API BOOL BCRSetScanAngle(DWORD dwScanAngle);

//
// BCRGetScanAngle
// Set the laser scan angle, normal or narrow.
//
BCRCTL_API BOOL BCRGetScanAngle(DWORD* lpdwScanAngle);

//
// BCRSendCommand
// Send the universal command to the barcode decoder.
//
BCRCTL_API BOOL BCRSendCommand(LPCTSTR lpszOptionsString);

//
// BCRReceiveCommand
// Retrieve the last commands sent to the barcode module.
//
BCRCTL_API BOOL BCRReceiveCommand(LPTSTR lpszOptionsString, DWORD dwOptionsStringLength);

//
// BCRSetCommandCofingFilePath
// This function set the command configuration file to BCR driver.
//
BCRCTL_API BOOL BCRSetCommandConfigFilePath (LPCTSTR lpszCommandConfigFile);

//
// BCRGetCommandConfigFilePath
// This function get the command configuration file from BCR driver.
//
BCRCTL_API BOOL BCRGetCommandConfigFilePath (LPTSTR lpszCommandConfigFile, DWORD dwFilePathLength);

//
// BCRGetDecoderConfig
// Retrieve the current configuration information of the barcode reader.
//
BCRCTL_API BOOL BCRGetDecoderConfig(LPTSTR lpszFileName, DWORD dwFilePathLength);

//
// BCRGetCommandFailedNotification
// Retrieve the notification message value and event name for sending configuration command.
//
BCRCTL_API BOOL BCRGetCommandFailedNotification(UINT* lpCommandFailedMsg, LPTSTR lpszCommaneFailedEventName, DWORD dwEventNameLength);

//
// BCRGetLastCommandError
// Retrieve the last command error.
//
BCRCTL_API BOOL BCRGetLastCommandError(DWORD* lpdwError);

//
// BCRTakeSnapShot
// Take a snap shot.
//
BCRCTL_API BOOL BCRTakeSnapShot(LPCTSTR lpszFileName);

//
// BCRGetFirmwareVersion
// Retrieve the information about the module firmware.
//
BCRCTL_API BOOL BCRGetFirmwareVersion(LPTSTR lpszFirmwareVersion, DWORD dwFirmwareVersionLength);

//
// BCRGetModuleType
// Retrieves the information about the module type
//  (Laser barcode reader or CMOS barcode reader).
//
BCRCTL_API BOOL BCRGetModuleType(DWORD* lpdwModuleType);

//
// BCRGetDriverVersion
// Retrieve the information about the driver version.
//
BCRCTL_API BOOL BCRGetDriverVersion(LPTSTR lpszDriverVersion, DWORD dwDriverVersionLength);

//
// BCRGetLibraryVersion 
// Retrieve the information about the bcrctl library.
//
BCRCTL_API BOOL BCRGetLibraryVersion(LPTSTR lpszVersionString, DWORD dwVersionStringLength);



#ifdef __cplusplus
}
#endif	// ifdef __cplusplus 

